summaryrefslogtreecommitdiffstats
path: root/qtjava/javalib/org/kde/qt/QGridLayout.java
diff options
context:
space:
mode:
Diffstat (limited to 'qtjava/javalib/org/kde/qt/QGridLayout.java')
-rw-r--r--qtjava/javalib/org/kde/qt/QGridLayout.java140
1 files changed, 70 insertions, 70 deletions
diff --git a/qtjava/javalib/org/kde/qt/QGridLayout.java b/qtjava/javalib/org/kde/qt/QGridLayout.java
index da08a17d..de127be3 100644
--- a/qtjava/javalib/org/kde/qt/QGridLayout.java
+++ b/qtjava/javalib/org/kde/qt/QGridLayout.java
@@ -3,98 +3,98 @@ package org.kde.qt;
import org.kde.qt.Qt;
-public class QGridLayout extends QLayout {
- protected QGridLayout(Class dummy){super((Class) null);}
+public class TQGridLayout extends TQLayout {
+ protected TQGridLayout(Class dummy){super((Class) null);}
public static final int TopLeft = 0;
public static final int TopRight = 1;
public static final int BottomLeft = 2;
public static final int BottomRight = 3;
- public native QMetaObject metaObject();
+ public native TQMetaObject metaObject();
public native String className();
- public QGridLayout(QWidget parent, int nRows, int nCols, int border, int spacing, String name) {
+ public TQGridLayout(TQWidget parent, int nRows, int nCols, int border, int spacing, String name) {
super((Class) null);
- newQGridLayout(parent,nRows,nCols,border,spacing,name);
+ newTQGridLayout(parent,nRows,nCols,border,spacing,name);
}
- private native void newQGridLayout(QWidget parent, int nRows, int nCols, int border, int spacing, String name);
- public QGridLayout(QWidget parent, int nRows, int nCols, int border, int spacing) {
+ private native void newTQGridLayout(TQWidget parent, int nRows, int nCols, int border, int spacing, String name);
+ public TQGridLayout(TQWidget parent, int nRows, int nCols, int border, int spacing) {
super((Class) null);
- newQGridLayout(parent,nRows,nCols,border,spacing);
+ newTQGridLayout(parent,nRows,nCols,border,spacing);
}
- private native void newQGridLayout(QWidget parent, int nRows, int nCols, int border, int spacing);
- public QGridLayout(QWidget parent, int nRows, int nCols, int border) {
+ private native void newTQGridLayout(TQWidget parent, int nRows, int nCols, int border, int spacing);
+ public TQGridLayout(TQWidget parent, int nRows, int nCols, int border) {
super((Class) null);
- newQGridLayout(parent,nRows,nCols,border);
+ newTQGridLayout(parent,nRows,nCols,border);
}
- private native void newQGridLayout(QWidget parent, int nRows, int nCols, int border);
- public QGridLayout(QWidget parent, int nRows, int nCols) {
+ private native void newTQGridLayout(TQWidget parent, int nRows, int nCols, int border);
+ public TQGridLayout(TQWidget parent, int nRows, int nCols) {
super((Class) null);
- newQGridLayout(parent,nRows,nCols);
+ newTQGridLayout(parent,nRows,nCols);
}
- private native void newQGridLayout(QWidget parent, int nRows, int nCols);
- public QGridLayout(QWidget parent, int nRows) {
+ private native void newTQGridLayout(TQWidget parent, int nRows, int nCols);
+ public TQGridLayout(TQWidget parent, int nRows) {
super((Class) null);
- newQGridLayout(parent,nRows);
+ newTQGridLayout(parent,nRows);
}
- private native void newQGridLayout(QWidget parent, int nRows);
- public QGridLayout(QWidget parent) {
+ private native void newTQGridLayout(TQWidget parent, int nRows);
+ public TQGridLayout(TQWidget parent) {
super((Class) null);
- newQGridLayout(parent);
+ newTQGridLayout(parent);
}
- private native void newQGridLayout(QWidget parent);
- public QGridLayout(int nRows, int nCols, int spacing, String name) {
+ private native void newTQGridLayout(TQWidget parent);
+ public TQGridLayout(int nRows, int nCols, int spacing, String name) {
super((Class) null);
- newQGridLayout(nRows,nCols,spacing,name);
+ newTQGridLayout(nRows,nCols,spacing,name);
}
- private native void newQGridLayout(int nRows, int nCols, int spacing, String name);
- public QGridLayout(int nRows, int nCols, int spacing) {
+ private native void newTQGridLayout(int nRows, int nCols, int spacing, String name);
+ public TQGridLayout(int nRows, int nCols, int spacing) {
super((Class) null);
- newQGridLayout(nRows,nCols,spacing);
+ newTQGridLayout(nRows,nCols,spacing);
}
- private native void newQGridLayout(int nRows, int nCols, int spacing);
- public QGridLayout(int nRows, int nCols) {
+ private native void newTQGridLayout(int nRows, int nCols, int spacing);
+ public TQGridLayout(int nRows, int nCols) {
super((Class) null);
- newQGridLayout(nRows,nCols);
+ newTQGridLayout(nRows,nCols);
}
- private native void newQGridLayout(int nRows, int nCols);
- public QGridLayout(int nRows) {
+ private native void newTQGridLayout(int nRows, int nCols);
+ public TQGridLayout(int nRows) {
super((Class) null);
- newQGridLayout(nRows);
+ newTQGridLayout(nRows);
}
- private native void newQGridLayout(int nRows);
- public QGridLayout() {
+ private native void newTQGridLayout(int nRows);
+ public TQGridLayout() {
super((Class) null);
- newQGridLayout();
+ newTQGridLayout();
}
- private native void newQGridLayout();
- public QGridLayout(QLayout parentLayout, int nRows, int nCols, int spacing, String name) {
+ private native void newTQGridLayout();
+ public TQGridLayout(TQLayout parentLayout, int nRows, int nCols, int spacing, String name) {
super((Class) null);
- newQGridLayout(parentLayout,nRows,nCols,spacing,name);
+ newTQGridLayout(parentLayout,nRows,nCols,spacing,name);
}
- private native void newQGridLayout(QLayout parentLayout, int nRows, int nCols, int spacing, String name);
- public QGridLayout(QLayout parentLayout, int nRows, int nCols, int spacing) {
+ private native void newTQGridLayout(TQLayout parentLayout, int nRows, int nCols, int spacing, String name);
+ public TQGridLayout(TQLayout parentLayout, int nRows, int nCols, int spacing) {
super((Class) null);
- newQGridLayout(parentLayout,nRows,nCols,spacing);
+ newTQGridLayout(parentLayout,nRows,nCols,spacing);
}
- private native void newQGridLayout(QLayout parentLayout, int nRows, int nCols, int spacing);
- public QGridLayout(QLayout parentLayout, int nRows, int nCols) {
+ private native void newTQGridLayout(TQLayout parentLayout, int nRows, int nCols, int spacing);
+ public TQGridLayout(TQLayout parentLayout, int nRows, int nCols) {
super((Class) null);
- newQGridLayout(parentLayout,nRows,nCols);
+ newTQGridLayout(parentLayout,nRows,nCols);
}
- private native void newQGridLayout(QLayout parentLayout, int nRows, int nCols);
- public QGridLayout(QLayout parentLayout, int nRows) {
+ private native void newTQGridLayout(TQLayout parentLayout, int nRows, int nCols);
+ public TQGridLayout(TQLayout parentLayout, int nRows) {
super((Class) null);
- newQGridLayout(parentLayout,nRows);
+ newTQGridLayout(parentLayout,nRows);
}
- private native void newQGridLayout(QLayout parentLayout, int nRows);
- public QGridLayout(QLayout parentLayout) {
+ private native void newTQGridLayout(TQLayout parentLayout, int nRows);
+ public TQGridLayout(TQLayout parentLayout) {
super((Class) null);
- newQGridLayout(parentLayout);
+ newTQGridLayout(parentLayout);
}
- private native void newQGridLayout(QLayout parentLayout);
- public native QSize sizeHint();
- public native QSize minimumSize();
- public native QSize maximumSize();
+ private native void newTQGridLayout(TQLayout parentLayout);
+ public native TQSize sizeHint();
+ public native TQSize minimumSize();
+ public native TQSize maximumSize();
public native void setRowStretch(int row, int stretch);
public native void setColStretch(int col, int stretch);
public native int rowStretch(int row);
@@ -105,34 +105,34 @@ public class QGridLayout extends QLayout {
public native int colSpacing(int col);
public native int numRows();
public native int numCols();
- public native QRect cellGeometry(int row, int col);
+ public native TQRect cellGeometry(int row, int col);
public native boolean hasHeightForWidth();
public native int heightForWidth(int arg1);
public native int minimumHeightForWidth(int arg1);
public native int expanding();
public native void invalidate();
- public native void addItem(QLayoutItemInterface arg1);
- public native void addItem(QLayoutItemInterface item, int row, int col);
- public native void addMultiCell(QLayoutItemInterface arg1, int fromRow, int toRow, int fromCol, int toCol, int align);
- public native void addMultiCell(QLayoutItemInterface arg1, int fromRow, int toRow, int fromCol, int toCol);
- public native void addWidget(QWidget arg1, int row, int col, int align);
- public native void addWidget(QWidget arg1, int row, int col);
- public native void addMultiCellWidget(QWidget arg1, int fromRow, int toRow, int fromCol, int toCol, int align);
- public native void addMultiCellWidget(QWidget arg1, int fromRow, int toRow, int fromCol, int toCol);
- public native void addLayout(QLayout layout, int row, int col);
- public native void addMultiCellLayout(QLayout layout, int fromRow, int toRow, int fromCol, int toCol, int align);
- public native void addMultiCellLayout(QLayout layout, int fromRow, int toRow, int fromCol, int toCol);
+ public native void addItem(TQLayoutItemInterface arg1);
+ public native void addItem(TQLayoutItemInterface item, int row, int col);
+ public native void addMultiCell(TQLayoutItemInterface arg1, int fromRow, int toRow, int fromCol, int toCol, int align);
+ public native void addMultiCell(TQLayoutItemInterface arg1, int fromRow, int toRow, int fromCol, int toCol);
+ public native void addWidget(TQWidget arg1, int row, int col, int align);
+ public native void addWidget(TQWidget arg1, int row, int col);
+ public native void addMultiCellWidget(TQWidget arg1, int fromRow, int toRow, int fromCol, int toCol, int align);
+ public native void addMultiCellWidget(TQWidget arg1, int fromRow, int toRow, int fromCol, int toCol);
+ public native void addLayout(TQLayout layout, int row, int col);
+ public native void addMultiCellLayout(TQLayout layout, int fromRow, int toRow, int fromCol, int toCol, int align);
+ public native void addMultiCellLayout(TQLayout layout, int fromRow, int toRow, int fromCol, int toCol);
public native void addRowSpacing(int row, int minsize);
public native void addColSpacing(int col, int minsize);
public native void expand(int rows, int cols);
public native void setOrigin(int arg1);
public native int origin();
- // QLayoutIterator iterator(); >>>> NOT CONVERTED
- public native void setGeometry(QRect arg1);
+ // TQLayoutIterator iterator(); >>>> NOT CONVERTED
+ public native void setGeometry(TQRect arg1);
public static native String tr(String arg1, String arg2);
public static native String tr(String arg1);
- protected native boolean findWidget(QWidget w, int[] r, int[] c);
- protected native void add(QLayoutItemInterface arg1, int row, int col);
+ protected native boolean findWidget(TQWidget w, int[] r, int[] c);
+ protected native void add(TQLayoutItemInterface arg1, int row, int col);
/** Deletes the wrapped C++ instance */
protected native void finalize() throws InternalError;
/** Delete the wrapped C++ instance ahead of finalize() */